;Project Lynxmotion Phoenix
;Description: 3DOF T-Hex, configuration file.
;      All Hardware connections (excl controls) and body dimensions 
;      are configurated in this file. Can be used with V2.1 and above
;Configuration version: V1.1 alfa
;Date: May 11, 2011
;Programmers: Jeroen Janssen (aka Xan)
;			  Kre Halvorsen (aka Zenta)
;
;Hardware setup: ABB2 with ATOM 28 Pro, SSC32 V2, (See further for connections)
;
;NEW IN V1.1
;   - Added speaker constant
;	- Added support for different leg lengths
;	- Optional 4DOF
;	- Optional Safety shut down when voltage drops
;
;--------------------------------------------------------------------
;[CONDITIONAL COMPILING] - COMMENT IF NOT WANTED
;c4DOF			 con 1	 	; Switch between 3DOF and 4DOF
;cTurnOffVol	 con 630 	; When uncomment the bot will turn off when 
							; the voltage drops below this setpoint (630 = 6.3V)
;--------------------------------------------------------------------
;[SERIAL CONNECTIONS]
cSSC_OUT   		con P11		;Output pin for (SSC32 RX) on BotBoard (Yellow)
cSSC_IN    		con P10		;Input pin for (SSC32 TX) on BotBoard (Blue)
cSSC_BAUD       con i115200	;SSC32 BAUD rate 38400 115200
;--------------------------------------------------------------------
;[BB2 PIN NUMBERS]
cEyesPin		con P8
cSpeakerPin		con P9
cVoltagePin		con 17		; Defines the analog input to read the voltage
							; for safety shutdown. (16=AX0=VS, 17=AX1=VL) 
;--------------------------------------------------------------------
;[SSC PIN NUMBERS]
cRRCoxaPin 		con P0	;Right Rear leg Hip Horizontal
cRRFemurPin 	con P1	;Right Rear leg Hip Vertical
cRRTibiaPin 	con P2	;Right Rear leg Knee

cRMCoxaPin 		con P4	;Right Middle leg Hip Horizontal
cRMFemurPin 	con P5	;Right Middle leg Hip Vertical
cRMTibiaPin 	con P6	;Right Middle leg Knee

cRFCoxaPin 		con P8	;Right Front leg Hip Horizontal
cRFFemurPin 	con P9	;Right Front leg Hip Vertical
cRFTibiaPin 	con P10	;Right Front leg Knee

cLRCoxaPin 		con P16	;Left Rear leg Hip Horizontal
cLRFemurPin 	con P17	;Left Rear leg Hip Vertical
cLRTibiaPin 	con P18	;Left Rear leg Knee

cLMCoxaPin 		con P20	;Left Middle leg Hip Horizontal
cLMFemurPin 	con P21	;Left Middle leg Hip Vertical
cLMTibiaPin 	con P22	;Left Middle leg Knee

cLFCoxaPin 		con P24	;Left Front leg Hip Horizontal
cLFFemurPin 	con P25	;Left Front leg Hip Vertical
cLFTibiaPin 	con P26	;Left Front leg Knee

#ifdef c4DOF ;Optional tars for 4DOF
  cRRTarsPin	con P3	;Right Rear leg Tars
  cRMTarsPin	con P7	;Right Middle leg Tars
  cRFTarsPin	con P11	;Right Front leg Tars
  cLRTarsPin	con P19	;Left Rear leg Tars
  cLMTarsPin	con P23	;Left Middle Leg Tars
  cLFTarsPin	con P27	;Left Front leg Tars
#endif
;--------------------------------------------------------------------
;[MIN/MAX ANGLES]
cRRCoxaMin1		con -260	;Mechanical limits of the Right Rear Leg, decimals = 1
cRRCoxaMax1		con 740
cRRFemurMin1	con -1010
cRRFemurMax1	con 950
cRRTibiaMin1	con -1060
cRRTibiaMax1	con 770

cRMCoxaMin1		con -530	;Mechanical limits of the Right Middle Leg, decimals = 1
cRMCoxaMax1		con 530
cRMFemurMin1	con -1010
cRMFemurMax1	con 950
cRMTibiaMin1	con -1060
cRMTibiaMax1	con 770

cRFCoxaMin1		con -580	;Mechanical limits of the Right Front Leg, decimals = 1
cRFCoxaMax1		con 740
cRFFemurMin1	con -1010
cRFFemurMax1	con 950
cRFTibiaMin1	con -1060
cRFTibiaMax1	con 770

cLRCoxaMin1		con -740	;Mechanical limits of the Left Rear Leg, decimals = 1
cLRCoxaMax1		con 260
cLRFemurMin1	con -950
cLRFemurMax1	con 1010
cLRTibiaMin1	con -770
cLRTibiaMax1	con 1060

cLMCoxaMin1		con -530	;Mechanical limits of the Left Middle Leg, decimals = 1
cLMCoxaMax1		con 530
cLMFemurMin1	con -950
cLMFemurMax1	con 1010
cLMTibiaMin1	con -770
cLMTibiaMax1	con 1060

cLFCoxaMin1		con -740	;Mechanical limits of the Left Front Leg, decimals = 1
cLFCoxaMax1		con 580
cLFFemurMin1	con -950
cLFFemurMax1	con 1010
cLFTibiaMin1	con -770
cLFTibiaMax1	con 1060

#ifdef c4DOF ;Optional tars for 4DOF
  cRRTarsMin1	con -1300
  cRRTarsMax1	con 500
  
  cRMTarsMin1	con -1300
  cRMTarsMax1	con 500
  
  cRFTarsMin1	con -1300
  cRFTarsMax1	con 500
  
  cLRTarsMin1	con -1300
  cLRTarsMax1	con 500
  
  cLMTarsMin1	con -1300
  cLMTarsMax1	con 500
  
  cLFTarsMin1	con -1300
  cLFTarsMax1	con 500
#endif
;--------------------------------------------------------------------
;[LEG DIMENSIONS]
;Universal dimensions for each leg
cXXCoxaLength  	con 29		;Length of the Coxa [mm]
cXXFemurLength 	con 76		;Length of the Femur [mm]
cXXTibiaLength 	con 106		;Length of the Tibia [mm]

cRRCoxaLength   con cXXCoxaLength	;Rigth Rear leg
cRRFemurLength  con cXXFemurLength
cRRTibiaLength  con cXXTibiaLength

cRMCoxaLength   con cXXCoxaLength	;Rigth middle leg
cRMFemurLength  con cXXFemurLength
cRMTibiaLength  con cXXTibiaLength

cRFCoxaLength   con cXXCoxaLength	;Rigth front leg
cRFFemurLength  con cXXFemurLength
cRFTibiaLength  con cXXTibiaLength

cLRCoxaLength   con cXXCoxaLength	;Left Rear leg
cLRFemurLength  con cXXFemurLength
cLRTibiaLength  con cXXTibiaLength

cLMCoxaLength   con cXXCoxaLength	;Left middle leg
cLMFemurLength  con cXXFemurLength
cLMTibiaLength  con cXXTibiaLength

cLFCoxaLength   con cXXCoxaLength	;Left front leg
cLFFemurLength  con cXXFemurLength
cLFTibiaLength  con cXXTibiaLength

#ifdef c4DOF
  cXXTarsLength con 85		;Length of the Tars [mm]

  cRRTarsLength  con cXXTarsLength
  cRMTarsLength  con cXXTarsLength
  cRFTarsLength  con cXXTarsLength
  cLRTarsLength  con cXXTarsLength
  cLMTarsLength  con cXXTarsLength
  cLFTarsLength  con cXXTarsLength
#endif
;--------------------------------------------------------------------
;[BODY DIMENSIONS]
cRRCoxaAngle1 	con -600	;Default Coxa setup angle, decimals = 1
cRMCoxaAngle1 	con 0		;Default Coxa setup angle, decimals = 1
cRFCoxaAngle1 	con 600		;Default Coxa setup angle, decimals = 1
cLRCoxaAngle1 	con -600	;Default Coxa setup angle, decimals = 1
cLMCoxaAngle1 	con 0		;Default Coxa setup angle, decimals = 1
cLFCoxaAngle1 	con 600		;Default Coxa setup angle, decimals = 1

cRROffsetX 		con -43		;Distance X from center of the body to the Right Rear coxa
cRROffsetZ 		con 82		;Distance Z from center of the body to the Right Rear coxa
cRMOffsetX 		con -63		;Distance X from center of the body to the Right Middle coxa
cRMOffsetZ 		con 0		;Distance Z from center of the body to the Right Middle coxa
cRFOffsetX 		con -43		;Distance X from center of the body to the Right Front coxa
cRFOffsetZ 		con -82		;Distance Z from center of the body to the Right Front coxa

cLROffsetX 		con 43		;Distance X from center of the body to the Left Rear coxa
cLROffsetZ 		con 82		;Distance Z from center of the body to the Left Rear coxa
cLMOffsetX 		con 63		;Distance X from center of the body to the Left Middle coxa
cLMOffsetZ 		con 0		;Distance Z from center of the body to the Left Middle coxa
cLFOffsetX 		con 43		;Distance X from center of the body to the Left Front coxa
cLFOffsetZ 		con -82		;Distance Z from center of the body to the Left Front coxa
;--------------------------------------------------------------------
;[START POSITIONS FEET]
cRRInitPosX 	con 53		;Start positions of the Right Rear leg
cRRInitPosY 	con 25
cRRInitPosZ 	con 91

cRMInitPosX 	con 105		;Start positions of the Right Middle leg
cRMInitPosY 	con 25
cRMInitPosZ 	con 0

cRFInitPosX 	con 53		;Start positions of the Right Front leg
cRFInitPosY 	con 25
cRFInitPosZ 	con -91

cLRInitPosX 	con 53		;Start positions of the Left Rear leg
cLRInitPosY 	con 25
cLRInitPosZ 	con 91

cLMInitPosX 	con 105		;Start positions of the Left Middle leg
cLMInitPosY 	con 25
cLMInitPosZ 	con 0

cLFInitPosX 	con 53		;Start positions of the Left Front leg
cLFInitPosY 	con 25
cLFInitPosZ 	con -91
;--------------------------------------------------------------------
;[Tars factors used in formula to calc Tarsus angle relative to the ground]
#ifdef c4DOF
  cTarsConst	con	720	;4DOF ONLY
  cTarsMulti	con 2	;4DOF ONLY
  cTarsFactorA	con 70	;4DOF ONLY
  cTarsFactorB	con 60	;4DOF ONLY
  cTarsFactorC	con 50	;4DOF ONLY
#endif
;--------------------------------------------------------------------
